Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2482)

Unified Diff: chrome/browser/conflicts/module_inspector_win.h

Issue 2873463002: Remove call to base::TaskTraits::WithPriority() in module_inspector_win.cc. (Closed)
Patch Set: CR-pmonette-5 Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/conflicts/module_inspector_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/conflicts/module_inspector_win.h
diff --git a/chrome/browser/conflicts/module_inspector_win.h b/chrome/browser/conflicts/module_inspector_win.h
index 3a036d69dc97e733cdc2640bf6cf2793a2b5f88b..d044cd06b1f9b427e9eb36aa2ba046946c78752d 100644
--- a/chrome/browser/conflicts/module_inspector_win.h
+++ b/chrome/browser/conflicts/module_inspector_win.h
@@ -59,10 +59,10 @@ class ModuleInspector {
// The modules are put in queue until they are sent for inspection.
std::queue<ModuleInfoKey> queue_;
// The traits used on the task that inspects the modules. It originally starts
// at a BACKGROUND priority, but is changed to USER_VISIBLE when
// IncreaseInspectionPriority() is called.
- base::TaskTraits inspection_task_traits_;
+ base::TaskPriority inspection_task_priority_;
// The vector of paths to %env_var%, used to account for differences in
// localization and where people keep their files.
« no previous file with comments | « no previous file | chrome/browser/conflicts/module_inspector_win.cc » ('j') | no next file with comments »
@@ -59,10 +59,10 @@ class ModuleInspector {
// The modules are put in queue until they are sent for inspection.
std::queue<ModuleInfoKey> queue_;
- // The traits used on the task that inspects the modules. It originally starts
- // at a BACKGROUND priority, but is changed to USER_VISIBLE when
+ // The TaskPriority of the task that inspects the modules. It originally
+ // starts at BACKGROUND priority, but is changed to USER_VISIBLE when
// IncreaseInspectionPriority() is called.

Powered by Google App Engine
This is Rietveld 408576698